@@ -50,13 +50,11 @@ TODO:
       -> background: #fff url() no-repeat left
 """
 __all__ = ['CSSStyleDeclaration', 'Property']
-__docformat__ = 'restructuredtext'
-__version__ = '$Id$'
 
 from .cssproperties import CSS2Properties
 from .property import Property
 import cssutils
-import xml.dom
+
 
 class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
     """The CSSStyleDeclaration class represents a single CSS declaration
@@ -84,18 +82,18 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
 
             >>> style = CSSStyleDeclaration(cssText='color: red')
             >>> style.color = 'green'
-            >>> print style.color
+            >>> print(style.color)
             green
             >>> del style.color
-            >>> print style.color
+            >>> print(style.color)
             <BLANKLINE>
 
     Format::
 
         [Property: Value Priority?;]* [Property: Value Priority?]?
     """
-    def __init__(self, cssText='', parentRule=None, readonly=False,
-                 validating=None):
+
+    def __init__(self, cssText='', parentRule=None, readonly=False, validating=None):
         """
         :param cssText:
             Shortcut, sets CSSStyleDeclaration.cssText
@@ -108,7 +106,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             a flag defining if this sheet should be validated on change.
             Defaults to None, which means defer to the parent stylesheet.
         """
-        super(CSSStyleDeclaration, self).__init__()
+        super().__init__()
         self._parentRule = parentRule
         self.validating = validating
         self.cssText = cssText
@@ -128,9 +126,11 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
 
     def __iter__(self):
         """Iterator of set Property objects with different normalized names."""
+
         def properties():
             for name in self.__nnames():
                 yield self.getProperty(name)
+
         return properties()
 
     def keys(self):
@@ -174,29 +174,45 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         TODO:
             implementation of known is not really nice, any alternative?
         """
-        known = ['_tokenizer', '_log', '_ttypes',
-                 '_seq', 'seq', 'parentRule', '_parentRule', 'cssText',
-                 'valid', 'wellformed', 'validating',
-                 '_readonly', '_profiles', '_validating']
+        known = [
+            '_tokenizer',
+            '_log',
+            '_ttypes',
+            '_seq',
+            'seq',
+            'parentRule',
+            '_parentRule',
+            'cssText',
+            'valid',
+            'wellformed',
+            'validating',
+            '_readonly',
+            '_profiles',
+            '_validating',
+        ]
         known.extend(CSS2Properties._properties)
         if n in known:
-            super(CSSStyleDeclaration, self).__setattr__(n, v)
+            super().__setattr__(n, v)
         else:
-            raise AttributeError('Unknown CSS Property, '
-                                 '``CSSStyleDeclaration.setProperty("%s", '
-                                 '...)`` MUST be used.' % n)
+            raise AttributeError(
+                'Unknown CSS Property, '
+                '``CSSStyleDeclaration.setProperty("%s", '
+                '...)`` MUST be used.' % n
+            )
 
     def __repr__(self):
-        return "cssutils.css.%s(cssText=%r)" % (
-                self.__class__.__name__,
-                self.getCssText(separator=' '))
+        return "cssutils.css.{}(cssText={!r})".format(
+            self.__class__.__name__,
+            self.getCssText(separator=' '),
+        )
 
     def __str__(self):
-        return "<cssutils.css.%s object length=%r (all: %r) at 0x%x>" % (
-                self.__class__.__name__,
-                self.length,
-                len(self.getProperties(all=True)),
-                id(self))
+        return "<cssutils.css.{} object length={!r} (all: {!r}) at 0x{:x}>".format(
+            self.__class__.__name__,
+            self.length,
+            len(self.getProperties(all=True)),
+            id(self),
+        )
 
     def __nnames(self):
         """Return iterator for all different names in order as set
@@ -205,7 +221,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         names = []
         for item in reversed(self.seq):
             val = item.value
-            if isinstance(val, Property) and not val.name in names:
+            if isinstance(val, Property) and val.name not in names:
                 names.append(val.name)
         return reversed(names)
 
@@ -219,7 +235,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         Example::
 
             >>> style = CSSStyleDeclaration(cssText='font-style:italic;')
-            >>> print style.fontStyle
+            >>> print(style.fontStyle)
             italic
         """
         return self.getPropertyValue(CSSName)
@@ -254,7 +270,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
 
             >>> style = CSSStyleDeclaration(cssText='font-style:italic;')
             >>> del style.fontStyle
-            >>> print style.fontStyle
+            >>> print(style.fontStyle)
             <BLANKLINE>
 
         """
@@ -262,7 +278,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
 
     def children(self):
         """Generator yielding any known child in this declaration including
-         *all* properties, comments or CSSUnknownrules.
+        *all* properties, comments or CSSUnknownrules.
         """
         for item in self._seq:
             yield item.value
@@ -286,13 +302,10 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         self._checkReadonly()
         tokenizer = self._tokenize2(cssText)
 
-        # for closures: must be a mutable
-        new = {'wellformed': True}
         def ident(expected, seq, token, tokenizer=None):
             # a property
 
-            tokens = self._tokensupto2(tokenizer, starttoken=token,
-                                       semicolon=True)
+            tokens = self._tokensupto2(tokenizer, starttoken=token, semicolon=True)
             if self._tokenvalue(tokens[-1]) == ';':
                 tokens.pop()
             property = Property(parent=self)
@@ -300,36 +313,46 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             if property.wellformed:
                 seq.append(property, 'Property')
             else:
-                self._log.error('CSSStyleDeclaration: Syntax Error in '
-                                'Property: %s' % self._valuestr(tokens))
+                self._log.error(
+                    'CSSStyleDeclaration: Syntax Error in '
+                    'Property: %s' % self._valuestr(tokens)
+                )
             # does not matter in this case
             return expected
 
         def unexpected(expected, seq, token, tokenizer=None):
             # error, find next ; or } to omit upto next property
             ignored = self._tokenvalue(token) + self._valuestr(
-                                self._tokensupto2(tokenizer,
-                                                  propertyvalueendonly=True))
-            self._log.error('CSSStyleDeclaration: Unexpected token, ignoring '
-                            'upto %r.' % ignored,token)
+                self._tokensupto2(tokenizer, propertyvalueendonly=True)
+            )
+            self._log.error(
+                'CSSStyleDeclaration: Unexpected token, ignoring ' 'upto %r.' % ignored,
+                token,
+            )
             # does not matter in this case
             return expected
 
         def char(expected, seq, token, tokenizer=None):
             # a standalone ; or error...
             if self._tokenvalue(token) == ';':
-                self._log.info('CSSStyleDeclaration: Stripped standalone semicolon'
-                                ': %s' % self._valuestr([token]), neverraise=True)
+                self._log.info(
+                    'CSSStyleDeclaration: Stripped standalone semicolon'
+                    ': %s' % self._valuestr([token]),
+                    neverraise=True,
+                )
                 return expected
             else:
                 return unexpected(expected, seq, token, tokenizer)
 
         # [Property: Value;]* Property: Value?
         newseq = self._tempSeq()
-        wellformed, expected = self._parse(expected=None,
-            seq=newseq, tokenizer=tokenizer,
+        wellformed, expected = self._parse(
+            expected=None,
+            seq=newseq,
+            tokenizer=tokenizer,
             productions={'IDENT': ident, 'CHAR': char},
-            default=unexpected)
+            default=unexpected,
+        )
         # wellformed set by parse
 
         for item in newseq:
@@ -338,10 +361,13 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         # do not check wellformed as invalid things are removed anyway
         self._setSeq(newseq)
 
-    cssText = property(_getCssText, _setCssText,
-                       doc="(DOM) A parsable textual representation of the "
-                           "declaration block excluding the surrounding curly "
-                           "braces.")
+    cssText = property(
+        _getCssText,
+        _setCssText,
+        doc="(DOM) A parsable textual representation of the "
+        "declaration block excluding the surrounding curly "
+        "braces.",
+    )
 
     def getCssText(self, separator=None):
         """
@@ -356,12 +382,16 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
 
     def _setParentRule(self, parentRule):
         self._parentRule = parentRule
-#        for x in self.children():
-#            x.parent = self
 
-    parentRule = property(lambda self: self._parentRule, _setParentRule,
+    #        for x in self.children():
+    #            x.parent = self
+
+    parentRule = property(
+        lambda self: self._parentRule,
+        _setParentRule,
         doc="(DOM) The CSS rule that contains this declaration block or "
-            "None if this CSSStyleDeclaration is not attached to a CSSRule.")
+        "None if this CSSStyleDeclaration is not attached to a CSSRule.",
+    )
 
     def getProperties(self, name=None, all=False):
         """
@@ -398,13 +428,12 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             properties = []
             for item in self.seq:
                 val = item.value
-                if isinstance(val, Property) and (
-                   (bool(nname) == False) or (val.name == nname)):
+                if isinstance(val, Property) and ((not nname) or (val.name == nname)):
                     properties.append(val)
             return properties
 
     def getProperty(self, name, normalize=True):
-        """
+        r"""
         :param name:
             of the CSS property, always lowercase (even if not normalized)
         :param normalize:
@@ -429,7 +458,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         return found
 
     def getPropertyCSSValue(self, name, normalize=True):
-        """
+        r"""
         :param name:
             of the CSS property, always lowercase (even if not normalized)
         :param normalize:
@@ -439,7 +468,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             If ``False`` may return **NOT** the effective value but the
             effective for the unnormalized name.
         :returns:
-            :class:`~cssutils.css.CSSValue`, the value of the effective
+            ``~cssutils.css.CSSValue``, the value of the effective
             property if it has been explicitly set for this declaration block.
 
         (DOM)
@@ -460,9 +489,11 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         """
         nname = self._normalize(name)
         if nname in self._SHORTHANDPROPERTIES:
-            self._log.info('CSSValue for shorthand property "%s" should be '
-                           'None, this may be implemented later.' %
-                           nname, neverraise=True)
+            self._log.info(
+                'CSSValue for shorthand property "%s" should be '
+                'None, this may be implemented later.' % nname,
+                neverraise=True,
+            )
 
         p = self.getProperty(name, normalize)
         if p:
@@ -471,7 +502,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             return None
 
     def getPropertyValue(self, name, normalize=True):
-        """
+        r"""
         :param name:
             of the CSS property, always lowercase (even if not normalized)
         :param normalize:
@@ -492,7 +523,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             return ''
 
     def getPropertyPriority(self, name, normalize=True):
-        """
+        r"""
         :param name:
             of the CSS property, always lowercase (even if not normalized)
         :param normalize:
@@ -513,7 +544,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             return ''
 
     def removeProperty(self, name, normalize=True):
-        """
+        r"""
         (DOM)
         Used to remove a CSS property if it has been explicitly set within
         this declaration block.
@@ -548,21 +579,20 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             # remove all properties with name == nname
             nname = self._normalize(name)
             for item in self.seq:
-                if not (isinstance(item.value, Property)
-                        and item.value.name == nname):
+                if not (isinstance(item.value, Property) and item.value.name == nname):
                     newseq.appendItem(item)
         else:
             # remove all properties with literalname == name
             for item in self.seq:
-                if not (isinstance(item.value, Property)
-                        and item.value.literalname == name):
+                if not (
+                    isinstance(item.value, Property) and item.value.literalname == name
+                ):
                     newseq.appendItem(item)
         self._setSeq(newseq)
         return r
 
-    def setProperty(self, name, value=None, priority='',
-                    normalize=True, replace=True):
-        """(DOM) Set a property value and priority within this declaration
+    def setProperty(self, name, value=None, priority='', normalize=True, replace=True):
+        r"""(DOM) Set a property value and priority within this declaration
         block.
 
         :param name:
@@ -636,8 +666,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             self.seq._readonly = True
 
         else:
-            self._log.warn('Invalid Property: %s: %s %s'
-                           % (name, value, priority))
+            self._log.warn('Invalid Property: {}: {} {}'.format(name, value, priority))
 
     def item(self, index):
         """(DOM) Retrieve the properties that have been explicitly set in
@@ -667,13 +696,15 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         except IndexError:
             return ''
 
-    length = property(lambda self: len(list(self.__nnames())),
-                      doc="(DOM) The number of distinct properties that have "
-                          "been explicitly in this declaration block. The "
-                          "range of valid indices is 0 to length-1 inclusive. "
-                          "These are properties with a different ``name`` "
-                          "only. :meth:`item` and :attr:`length` work on the "
-                          "same set here.")
+    length = property(
+        lambda self: len(list(self.__nnames())),
+        doc="(DOM) The number of distinct properties that have "
+        "been explicitly in this declaration block. The "
+        "range of valid indices is 0 to length-1 inclusive. "
+        "These are properties with a different ``name`` "
+        "only. :meth:`item` and :attr:`length` work on the "
+        "same set here.",
+    )
 
     def _getValidating(self):
         try:
@@ -689,16 +720,18 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
     def _setValidating(self, validating):
         self._validating = validating
 
-    validating = property(_getValidating, _setValidating,
-                          doc="If ``True`` this declaration validates "
-                          "contained properties. The parent StyleSheet "
-                          "validation setting does *always* win though so "
-                          "even if validating is True it may not validate "
-                          "if the StyleSheet defines else!")
+    validating = property(
+        _getValidating,
+        _setValidating,
+        doc="If ``True`` this declaration validates "
+        "contained properties. The parent StyleSheet "
+        "validation setting does *always* win though so "
+        "even if validating is True it may not validate "
+        "if the StyleSheet defines else!",
+    )
 
     def _getValid(self):
         """Check each contained property for validity."""
         return all(prop.valid for prop in self.getProperties())
 
-    valid = property(_getValid,
-                     doc='``True`` if each property is valid.')
+    valid = property(_getValid, doc='``True`` if each property is valid.')
